"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.eslintConfig = eslintConfig;

var _confusingBrowserGlobals = _interopRequireDefault(require("confusing-browser-globals"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// @ts-check

/**
 * @param {EsLintConfig} params
 */
function eslintConfig(params) {
  var _params$root, _params$root2, _params$root3, _params$root4, _params$src, _ref, _params$src2, _params$src3;

  const rootJavaScriptConfig = {
    root: true,
    env: {
      browser: false,
      es6: true,
      node: true,
      ...(params === null || params === void 0 ? void 0 : (_params$root = params.root) === null || _params$root === void 0 ? void 0 : _params$root.env)
    },
    parser: 'babel-eslint',
    plugins: ['import'],
    extends: ['eslint:recommended', 'prettier', ...((params === null || params === void 0 ? void 0 : (_params$root2 = params.root) === null || _params$root2 === void 0 ? void 0 : _params$root2.extends) || [])],
    parserOptions: {
      ecmaVersion: 2018,
      ...(params === null || params === void 0 ? void 0 : (_params$root3 = params.root) === null || _params$root3 === void 0 ? void 0 : _params$root3.parserOptions)
    },
    rules: {
      'array-callback-return': 'warn',
      'default-case': ['warn', {
        commentPattern: '^no default$'
      }],
      'dot-location': ['warn', 'property'],
      eqeqeq: ['warn', 'smart'],
      'new-parens': 'warn',
      'no-array-constructor': 'warn',
      'no-caller': 'warn',
      'no-cond-assign': ['warn', 'except-parens'],
      'no-const-assign': 'warn',
      'no-control-regex': 'warn',
      'no-delete-var': 'warn',
      'no-dupe-args': 'warn',
      'no-dupe-class-members': 'warn',
      'no-dupe-keys': 'warn',
      'no-duplicate-case': 'warn',
      'no-empty-character-class': 'warn',
      'no-empty-pattern': 'warn',
      'no-eval': 'warn',
      'no-ex-assign': 'warn',
      'no-extend-native': 'warn',
      'no-extra-bind': 'warn',
      'no-extra-label': 'warn',
      'no-fallthrough': 'warn',
      'no-func-assign': 'warn',
      'no-implied-eval': 'warn',
      'no-invalid-regexp': 'warn',
      'no-iterator': 'warn',
      'no-label-var': 'warn',
      'no-labels': ['warn', {
        allowLoop: true,
        allowSwitch: false
      }],
      'no-lone-blocks': 'warn',
      'no-loop-func': 'warn',
      'no-mixed-operators': ['warn', {
        groups: [['&', '|', '^', '~', '<<', '>>', '>>>'], ['==', '!=', '===', '!==', '>', '>=', '<', '<='], ['&&', '||'], ['in', 'instanceof']],
        allowSamePrecedence: false
      }],
      'no-multi-str': 'warn',
      'no-native-reassign': 'warn',
      'no-negated-in-lhs': 'warn',
      'no-new-func': 'warn',
      'no-new-object': 'warn',
      'no-new-symbol': 'warn',
      'no-new-wrappers': 'warn',
      'no-obj-calls': 'warn',
      'no-octal': 'warn',
      'no-octal-escape': 'warn',
      // TODO: Remove this option in the next major release of CRA.
      // https://eslint.org/docs/user-guide/migrating-to-6.0.0#-the-no-redeclare-rule-is-now-more-strict-by-default
      'no-redeclare': ['warn', {
        builtinGlobals: false
      }],
      'no-regex-spaces': 'warn',
      'no-restricted-syntax': ['warn', 'WithStatement'],
      'no-script-url': 'warn',
      'no-self-assign': 'warn',
      'no-self-compare': 'warn',
      'no-sequences': 'warn',
      'no-shadow-restricted-names': 'warn',
      'no-sparse-arrays': 'warn',
      'no-template-curly-in-string': 'warn',
      'no-this-before-super': 'warn',
      'no-throw-literal': 'warn',
      'no-undef': 'error',
      'no-restricted-globals': ['error'].concat(_confusingBrowserGlobals.default),
      'no-unreachable': 'warn',
      'no-unused-expressions': ['error', {
        allowShortCircuit: true,
        allowTernary: true,
        allowTaggedTemplates: true
      }],
      'no-unused-labels': 'warn',
      'no-use-before-define': ['warn', {
        functions: false,
        classes: false,
        variables: false
      }],
      'no-useless-computed-key': 'warn',
      'no-useless-concat': 'warn',
      'no-useless-constructor': 'warn',
      'no-useless-escape': 'warn',
      'no-useless-rename': ['warn', {
        ignoreDestructuring: false,
        ignoreImport: false,
        ignoreExport: false
      }],
      'no-with': 'warn',
      'no-whitespace-before-property': 'warn',
      'require-yield': 'warn',
      'rest-spread-spacing': ['warn', 'never'],
      'unicode-bom': ['warn', 'never'],
      'use-isnan': 'warn',
      'valid-typeof': 'warn',
      'no-restricted-properties': ['error', {
        object: 'require',
        property: 'ensure',
        message: 'Please use import() instead. More info: https://facebook.github.io/create-react-app/docs/code-splitting'
      }, {
        object: 'System',
        property: 'import',
        message: 'Please use import() instead. More info: https://facebook.github.io/create-react-app/docs/code-splitting'
      }],
      'getter-return': 'warn',
      'import/first': 'error',
      'import/no-amd': 'error',
      'import/no-webpack-loader-syntax': 'error',
      'no-unused-vars': ['error', {
        ignoreRestSiblings: true,
        argsIgnorePattern: '_.*'
      }],
      ...(params === null || params === void 0 ? void 0 : (_params$root4 = params.root) === null || _params$root4 === void 0 ? void 0 : _params$root4.rules)
    }
  };
  const typeScript = {
    parser: '@typescript-eslint/parser',
    parserOptions: {
      project: './tsconfig.json',
      ecmaVersion: 2018,
      sourceType: 'module',
      ecmaFeatures: {
        jsx: true
      },
      warnOnUnsupportedTypeScriptVersion: true,
      ...(params === null || params === void 0 ? void 0 : (_params$src = params.src) === null || _params$src === void 0 ? void 0 : _params$src.parserOptions)
    },
    plugins: ['import', '@typescript-eslint'],
    extends: ['eslint:recommended', 'plugin:@typescript-eslint/eslint-recommended', 'plugin:@typescript-eslint/recommended', 'plugin:@typescript-eslint/recommended-requiring-type-checking', 'prettier', 'prettier/@typescript-eslint', ...((_ref = params === null || params === void 0 ? void 0 : (_params$src2 = params.src) === null || _params$src2 === void 0 ? void 0 : _params$src2.extends) !== null && _ref !== void 0 ? _ref : [])],
    rules: {
      strict: ['warn', 'never'],
      // TypeScript's `noFallthroughCasesInSwitch` option is more robust (#6906)
      'default-case': 'off',
      // 'tsc' already handles this (https://github.com/typescript-eslint/typescript-eslint/issues/291)
      'no-dupe-class-members': 'off',
      // 'tsc' already handles this (https://github.com/typescript-eslint/typescript-eslint/issues/477)
      'no-undef': 'off',
      // Add TypeScript specific rules (and turn off ESLint equivalents)
      '@typescript-eslint/consistent-type-assertions': 'warn',
      'no-array-constructor': 'off',
      '@typescript-eslint/no-array-constructor': 'warn',
      '@typescript-eslint/no-namespace': 'error',
      'no-use-before-define': 'off',
      '@typescript-eslint/no-use-before-define': ['warn', {
        functions: false,
        classes: false,
        variables: false,
        typedefs: false
      }],
      'no-unused-expressions': 'off',
      '@typescript-eslint/no-unused-expressions': ['error', {
        allowShortCircuit: true,
        allowTernary: true,
        allowTaggedTemplates: true
      }],
      'no-unused-vars': 'off',
      '@typescript-eslint/no-unused-vars': ['error', {
        ignoreRestSiblings: true,
        argsIgnorePattern: '_.*'
      }],
      'no-useless-constructor': 'off',
      '@typescript-eslint/no-useless-constructor': 'warn',
      '@typescript-eslint/explicit-function-return-type': 'off',
      '@typescript-eslint/interface-name-prefix': 'warn',
      ...(params === null || params === void 0 ? void 0 : (_params$src3 = params.src) === null || _params$src3 === void 0 ? void 0 : _params$src3.rules)
    }
  };
  return { ...rootJavaScriptConfig,
    overrides: [{
      files: ['src/**/*.ts?(x)', 'src/**/*.js?(x)'],
      ...typeScript
    }]
  };
}
//# sourceMappingURL=eslint.config.js.map